==> jupyterlab_tabnine-0.0.4.tar.gz: jupyterlab_tabnine-0.0.4/README.md <==
[twitter-shield]: https://img.shields.io/twitter/follow/Tabnine_?style=social
[twitter-url]: https://bit.ly/2WHsEtD
[github-shield]: https://img.shields.io/github/stars/codota/Tabnine?style=social
[github-url]: https://bit.ly/36iGtUU
[youtube-shield]: https://img.shields.io/youtube/views/TKLkXh_c-Gw?style=social
[youtube-url]: https://bit.ly/36slY7c

[![Github Repo][github-shield]][github-url]
[![Youtube Demo Video][youtube-shield]][youtube-url]
[![Twitter Follow][twitter-shield]][twitter-url]
[![Gitpod ready-to-code](https://img.shields.io/badge/Gitpod-ready--to--code-908a85?logo=gitpod)](https://gitpod.io/from-referrer/)

# Supercharge Your Development Workflow

Tabnine is the AI code completion tool **trusted by millions of developers** to code faster with fewer errors. Whether you are a new dev or a seasoned pro, working solo or part of a team, Tabnine will help push your productivity to new heights while cutting your QA time – all in your favorite IDE.
<br />

## Tabnine - Your AI Assistant

Whether you call it **IntelliSense, intelliCode, autocomplete, AI-assisted code completion, AI-powered code completion, AI copilot, AI code snippets, code suggestion, code prediction, code hinting**, or **content assist**, you probably already know that it can save you tons of time, easily cutting your keystrokes in half.

Powered by sophisticated **machine learning models** trained on billions of lines of trusted **Open Source code** from GitHub, Tabnine is the most advanced **AI-powered code completion** copilot available today. And like GitHub, it is an essential tool for professional developers.

<img src="assets/with-and-without-tabnine-light.gif" width="75%" alt="Tabnine for Jupyterlab">
<br />

## Tabnine’s AI Engine

Tabnine delivers three times the AI for better collaboration, better privacy protection, and better code completion.

<img src="https://github.com/codota/TabNine/raw/master/resources/tabnine-engine.gif" width="75%" alt="Tabnine Engine">
<br />

## Bigger Team - Better AI

**Tools Your Team Can Count On**
Coding collaboration just got easier. Both **Tabnine Basic** and **Tabnine Pro** now include our growing suite of tools for teams. Name your team, invite team members, and manage your account all from your **My Tabnine** profile.

**Learn & Grow as You Go**
The more team members you invite and add, the faster Tabnine’s **Team Trained AI**, and **Private Codebase Trained AI** will learn your team’s projects, preferences, and patterns, suggesting even more accurate code completions.
<br />

## Privacy & Compliance

**Your Code Is Never Shared**
At Tabnine we know privacy is paramount. All three of Tabnine's AI code completion models can be run locally, on your machine, and NEVER share your code or use it as part of Tabnine’s open-source trained AI.

**Your Data is Never Shared**
Both the Team Trained AI and Private Codebase AI store all your AI training data locally on your machines, helping ensure compliance while providing you and your team with complete control and custody of your data and code.

Find out more about how we keep your code private [here](https://www.tabnine.com/code-privacy)
<br />

## All the Languages You Love

### Including:

|     Python     |   Javascript    |   Java   |
| :------------: | :-------------: | :------: |
|  extended JS   |    **React**    |   PHP    |
| **Typescript** |    C Header     |   Bash   |
|       ML       |      Swift      | **Ruby** |
|      Perl      |    **Rust**     |   SQL    |
|    **Vue**     |       F#        |  Scala   |
|     Julia      |      TOML       |  Shell   |
|      YMAL      | **C / C++/ C#** |   HTML   |
|      Lua       |    Markdown     | Haskell  |
|     **Go**     |   Objective C   | **JSON** |
|   CSS / SCSS   |   **Angular**   |  Kotlin  |

---

### Speed Up Your Development

Get quick concise code suggestions you can count on for easy in-flow approval and integration. You’ll never need to memorize syntax, worry about typos, or hunt for snippets again.
<br />

### Stay in Flow

Tabnine serves up suggestions for code completions right in your IDE, with no distractions and no downtime.
<br />

### Code Discovery

Tabnine's AI scans and learns from the best open-source coding practices from across the globe, freeing you to focus on problems that haven't already been solved.
<br />

### Ace Your Code Review

Reduce development costs, eliminate unnecessary QA-ing, and deliver final code faster with AI trained on the most trusted open-source permissive license repositories.

---

## Pick the Plan that Works Best for You

### Tabnine Basic

**No Credit Card, No Commitment - Just Code**
[Get Tabnine](https://www.tabnine.com/install/vscode?utm_source=ide_marketplace&utm_medium=organic&utm_campaign=jupyter_lab_marketplace)
<br />

### Tabnine Pro

**Pro Tools for Professional Developers**
[Upgrade to Pro](https://www.tabnine.com/pro?utm_source=ide_marketplace&utm_medium=organic&utm_campaign=jupyter_lab_marketplace)
<br />

### Tabnine Free Student Pro Plan

**Investing In Our Community**
We know that tuition, books, rent, and food can get crazy expensive, that’s why Tabnine helps support the community and the dev superstars of tomorrow with a 100% free Tabnine Student license with **all our Pro perks** renewable for as long as you are a student.
[Student? Click here](https://www.tabnine.com/students?utm_source=ide_marketplace&utm_medium=organic&utm_campaign=jupyter_lab_marketplace)

---

## Easy Installation

Simply run this command line in you terminal:

`pip install --upgrade jupyterlab_tabnine`

---

### FAQ

Got a question? We’ve got the answer - Check out our [FAQ](https://www.tabnine.com/faq?utm_source=ide_marketplace&utm_medium=organic&utm_campaign=jupyter_lab_marketplace) page
<br />

### Tabnine Support

Having some trouble with installation? Something not working the way you hoped? **Tabnine Support** is always happy to help. Feel free to contact us anytime at support@tabnine.com
<br />

### Tabnine Hub

A quick click on **_Tabnine_** on your IDE status bar takes you directly to your **_Tabnine Hub_** where you can easily update and manage all your account options and customize your suggestion preferences.
<br />

### Usage

After installation, navigate to the **_Tabnine Settings_** page (Open **_Settings_** from the Command Palette) and verify that Tabnine is successfully loaded (as shown in these [screenshots](https://code.visualstudio.com/docs/getstarted/userinterface#_command-palette)).

Tabnine is a textual autocomplete extension. When you type a specific string in your editor, you will be shown the Tabnine completion dialog box with suggestions for completing the code you’ve begun typing.
<br />

### Deep Completion

Deep Tabnine is trained on millions of files from GitHub. During training, Tabnine’s goal is to predict the next token given the tokens that came before. To achieve this goal, Tabnine learns complex behavior, such as type inference in dynamically typed languages.

Deep Tabnine can use subtle clues that are difficult for traditional tools to access. For example, the return type of `app.get_user()` is assumed to be an object with setter methods, while the return type of `app.get_users()` is assumed to be a list.

Deep Tabnine is based on GPT-2, which uses the **_Transformers Network Architecture_**. This architecture was first developed to solve problems in natural language processing. Although modeling code and modeling natural language might appear to be unrelated tasks, modeling code requires understanding English in some unexpected ways.

- Tabnine Indexes your entire project and determines which files to ignore by reading your `.gitignore`
- Tabnine cuts your number of keystrokes in half and eliminates unnecessary typos
- Tabnine works right out of the box ensuring frictionless installation and configuration
- Tabnine offers code completion suggestions in less than 10 milliseconds
  <br />

---

### Communities

- [Join the Tabnine Discord server](https://discord.gg/5GnbDg5Jmg)
- [Join the Tabnine community in Slack](https://join.slack.com/t/tabnine-community/shared_invite/zt-mi5n0v6f-4W0Ap4yAUQXS~nVvxwSoJg)

[<img src="https://raw.githubusercontent.com/codota/tabnine-vscode/master/assets/teams-banner-1.png" width=50%>](https://www.tabnine.com/refer-a-friend?utm_source=ide_marketplace&utm_medium=organic&utm_campaign=jupyter_lab_marketplace")

### **_Recommended by developers everywhere:_**

<img src="https://raw.githubusercontent.com/codota/tabnine-vscode/master/assets/twitter-ps-27.png" alt="William Candillon Tweet" width="50%">

<img src="https://raw.githubusercontent.com/codota/tabnine-vscode/master/assets/twitter-ps-7.png" alt="Imed Boumalek Tweet" width="50%">

<img src="https://raw.githubusercontent.com/codota/tabnine-vscode/master/assets/twitter-ps-14.png" alt="ramnivas Tweet" width="50%">

<img src="https://raw.githubusercontent.com/codota/tabnine-vscode/master/assets/twitter-ps-16.png" alt="bob paskar Tweet" width="50%">

<img src="https://raw.githubusercontent.com/codota/tabnine-vscode/master/assets/twitter-ps-19.png" alt="Nick Radford Tweet" width="50%">

<img src="https://raw.githubusercontent.com/codota/tabnine-vscode/master/assets/twitter-ps-28.png" alt="Hugues BR Tweet" width="50%">

<img src="https://raw.githubusercontent.com/codota/tabnine-vscode/master/assets/twitter-ps-32.png" alt="JohnyTheCarrot Tweet" width="50%">

<img src="https://raw.githubusercontent.com/codota/tabnine-vscode/master/assets/twitter-ps-33.png" alt="Donald E Fredrick Tweet" width="50%">

<img src="https://raw.githubusercontent.com/codota/tabnine-vscode/master/assets/twitter-ps-36.png" alt="Joshua Kelly Tweet" width="50%">

<img src="https://raw.githubusercontent.com/codota/tabnine-vscode/master/assets/twitter-ps-38.png" alt="JDerek Braid Tweet" width="50%">

---

- **Q: Can I install Tabnine on multiple machines?**
- A: You can use your Tabnine license on as many computers and operating systems as you like. All Tabnine Licenses are per-user, rather than per-machine.
  <br />
  <br />

- **Q: Is there a Tabnine Student program?**
- A: Yes, If you’re a student, you can register for Tabnine Pro for FREE using your school email address. [Get Tabnine Student now](https://www.tabnine.com/students?utm_source=ide_marketplace&utm_medium=organic&utm_campaign=jupyter_lab_marketplace)
  <br />
  <br />

- **Q: Does Tabnine use a model trained on safe, open-source code for completions?**
- A: Yes, all Tabnine code completions are based on trusted, open-source code with permissive licenses.
  <br />
  <br />

- **Q: Does the Tabnine Private Codebase AI share my code?**
- A: NEVER! Your code is always kept local and 100% private for you and your team. It’s never used to train the Tabnine Private Codebase AI - That’s the Tabnine Privacy Promise.
  <br />
  <br />

- **Q: Do All Three Tabnie AI Models work together?**
- A: Yes, the three models work in tandem, simultaneously providing unparalleled AI accuracy. Tabnine’s Open-Source Trained AI bases its suggestions on trusted public code with permissive licenses while the Private Codebase AI and Team Trained AI learn from you and your team’s preferences, code selections, and ongoing AI interactions.
  <br />
  <br />

- **Q: Can I run Tabnine locally, or do I need to use the Cloud?**
- A: You can run Tabnine locally or on the cloud, you choose! Regardless, your code is never shared or used as part of Tabnine’s Open-Source Trained AI - That’s the Tabnine Privacy Promise.
  <br />
  <br />

- **Q: Does Tabnine work in multiple IDEs?**
- A: Yes, Tabnine works with all your favorite IDEs, and in the most popular languages, libraries, and frameworks. See the full list of IDEs and languages [HERE](https://www.tabnine.com/install?utm_source=ide_marketplace&utm_medium=organic&utm_campaign=jupyter_lab_marketplace)
  <br />
  <br />

- **Q: What is the difference between Tabnine Basic and Tabnine Pro?**
- A: Tabnine Pro uses our advanced AI Model trained on more than a billion lines of open-source code and works with teams of up to 30. Tabnine Basic uses a smaller AI model and works with teams of three or less.
  <br />
  <br />

- **Q: What type of online payments are accepted?**
- A: Tabnine accepts all major credit cards and debit cards, including Visa, Mastercard, American Express, and more. Tabnine also accepts PayPal, Google Pay, Apple Pay, as well as additional payment options that may be available in your specific location (such as Alipay).

==> jupyterlab_tabnine-0.0.17.tar.gz: jupyterlab_tabnine-0.0.17/README.md <==
[twitter-shield]: https://img.shields.io/twitter/follow/Tabnine_?style=social
[twitter-url]: https://bit.ly/2WHsEtD
[github-shield]: https://img.shields.io/github/stars/codota/Tabnine?style=social
[github-url]: https://bit.ly/36iGtUU
[youtube-shield]: https://img.shields.io/youtube/views/TKLkXh_c-Gw?style=social
[youtube-url]: https://bit.ly/36slY7c

[![Github Repo][github-shield]][github-url]
[![Youtube Demo Video][youtube-shield]][youtube-url]
[![Twitter Follow][twitter-shield]][twitter-url]
[![Gitpod ready-to-code](https://img.shields.io/badge/Gitpod-ready--to--code-908a85?logo=gitpod)](https://gitpod.io/from-referrer/)

# Supercharge Your Development Workflow

Tabnine is the AI code completion tool **trusted by millions of developers** to code faster with fewer errors. Whether you are a new dev or a seasoned pro, working solo or part of a team, Tabnine will help push your productivity to new heights while cutting your QA time – all in your favorite IDE.
<br />

## Tabnine - Your AI Assistant

Whether you call it **IntelliSense, intelliCode, autocomplete, AI-assisted code completion, AI-powered code completion, AI copilot, AI code snippets, code suggestion, code prediction, code hinting**, or **content assist**, you probably already know that it can save you tons of time, easily cutting your keystrokes in half.

Powered by sophisticated **machine learning models** trained on billions of lines of trusted **Open Source code** from GitHub, Tabnine is the most advanced **AI-powered code completion** copilot available today. And like GitHub, it is an essential tool for professional developers.

<img src="https://raw.githubusercontent.com/codota/tabnine-vscode/master/assets/with-and-without-tabnine-light.gif" width="75%" alt="Tabnine for Jupyterlab">
<br />

## Tabnine’s AI Engine

Tabnine delivers three times the AI for better collaboration, better privacy protection, and better code completion.

<img src="https://github.com/codota/TabNine/raw/master/resources/tabnine-engine.gif" width="75%" alt="Tabnine Engine">
<br />

## Bigger Team - Better AI

**Tools Your Team Can Count On**
Coding collaboration just got easier. Both **Tabnine Basic** and **Tabnine Pro** now include our growing suite of tools for teams. Name your team, invite team members, and manage your account all from your **My Tabnine** profile.

**Learn & Grow as You Go**
The more team members you invite and add, the faster Tabnine’s **Team Trained AI**, and **Private Codebase Trained AI** will learn your team’s projects, preferences, and patterns, suggesting even more accurate code completions.
<br />

## Privacy & Compliance

**Your Code Is Never Shared**
At Tabnine we know privacy is paramount. All three of Tabnine's AI code completion models can be run locally, on your machine, and NEVER share your code or use it as part of Tabnine’s open-source trained AI.

**Your Data is Never Shared**
Both the Team Trained AI and Private Codebase AI store all your AI training data locally on your machines, helping ensure compliance while providing you and your team with complete control and custody of your data and code.

Find out more about how we keep your code private [here](https://www.tabnine.com/code-privacy)
<br />

## All the Languages You Love

### Including:

|     Python     |   Javascript    |   Java   |
| :------------: | :-------------: | :------: |
|  extended JS   |    **React**    |   PHP    |
| **Typescript** |    C Header     |   Bash   |
|       ML       |      Swift      | **Ruby** |
|      Perl      |    **Rust**     |   SQL    |
|    **Vue**     |       F#        |  Scala   |
|     Julia      |      TOML       |  Shell   |
|      YMAL      | **C / C++/ C#** |   HTML   |
|      Lua       |    Markdown     | Haskell  |
|     **Go**     |   Objective C   | **JSON** |
|   CSS / SCSS   |   **Angular**   |  Kotlin  |

---

### Speed Up Your Development

Get quick concise code suggestions you can count on for easy in-flow approval and integration. You’ll never need to memorize syntax, worry about typos, or hunt for snippets again.
<br />

### Stay in Flow

Tabnine serves up suggestions for code completions right in your IDE, with no distractions and no downtime.
<br />

### Code Discovery

Tabnine's AI scans and learns from the best open-source coding practices from across the globe, freeing you to focus on problems that haven't already been solved.
<br />

### Ace Your Code Review

Reduce development costs, eliminate unnecessary QA-ing, and deliver final code faster with AI trained on the most trusted open-source permissive license repositories.

---

## Pick the Plan that Works Best for You

### Tabnine Basic

**No Credit Card, No Commitment - Just Code**
[Get Tabnine](https://www.tabnine.com/install?utm_source=ide_marketplace&utm_medium=organic&utm_campaign=jupyter_lab_marketplace)
<br />

### Tabnine Pro

**Pro Tools for Professional Developers**
[Upgrade to Pro](https://www.tabnine.com/pro?utm_source=ide_marketplace&utm_medium=organic&utm_campaign=jupyter_lab_marketplace)
<br />

### Tabnine Free Student Pro Plan

**Investing In Our Community**
We know that tuition, books, rent, and food can get crazy expensive, that’s why Tabnine helps support the community and the dev superstars of tomorrow with a 100% free Tabnine Student license with **all our Pro perks** renewable for as long as you are a student.
[Student? Click here](https://www.tabnine.com/students?utm_source=ide_marketplace&utm_medium=organic&utm_campaign=jupyter_lab_marketplace)

---

## Easy Installation

Simply run this command line in you terminal:

`pip install --upgrade jupyterlab_tabnine`

---

### FAQ

Got a question? We’ve got the answer - Check out our [FAQ](https://www.tabnine.com/faq?utm_source=ide_marketplace&utm_medium=organic&utm_campaign=jupyter_lab_marketplace) page
<br />

### Tabnine Support

Having some trouble with installation? Something not working the way you hoped? **Tabnine Support** is always happy to help. Feel free to contact us anytime at support@tabnine.com
<br />

### Tabnine Hub

A quick click on **_Tabnine_** on your IDE status bar takes you directly to your **_Tabnine Hub_** where you can easily update and manage all your account options and customize your suggestion preferences.
<br />

### Usage

Tabnine is a textual autocomplete extension. When you type a specific string in your editor, you will be shown the Tabnine completion dialog box with suggestions for completing the code you’ve begun typing.
<br />

### Deep Completion

Deep Tabnine is trained on millions of files from GitHub. During training, Tabnine’s goal is to predict the next token given the tokens that came before. To achieve this goal, Tabnine learns complex behavior, such as type inference in dynamically typed languages.

Deep Tabnine can use subtle clues that are difficult for traditional tools to access. For example, the return type of `app.get_user()` is assumed to be an object with setter methods, while the return type of `app.get_users()` is assumed to be a list.

Deep Tabnine is based on GPT-2, which uses the **_Transformers Network Architecture_**. This architecture was first developed to solve problems in natural language processing. Although modeling code and modeling natural language might appear to be unrelated tasks, modeling code requires understanding English in some unexpected ways.

- Tabnine Indexes your entire project and determines which files to ignore by reading your `.gitignore`
- Tabnine cuts your number of keystrokes in half and eliminates unnecessary typos
- Tabnine works right out of the box ensuring frictionless installation and configuration
- Tabnine offers code completion suggestions in less than 10 milliseconds
  <br />

---

### Communities

- [Join the Tabnine Discord server](https://discord.gg/5GnbDg5Jmg)
- [Join the Tabnine community in Slack](https://join.slack.com/t/tabnine-community/shared_invite/zt-mi5n0v6f-4W0Ap4yAUQXS~nVvxwSoJg)

[<img src="https://raw.githubusercontent.com/codota/tabnine-vscode/master/assets/teams-banner-1.png" width=50%>](https://www.tabnine.com/refer-a-friend?utm_source=ide_marketplace&utm_medium=organic&utm_campaign=jupyter_lab_marketplace")

### **_Recommended by developers everywhere:_**

<img src="https://raw.githubusercontent.com/codota/tabnine-vscode/master/assets/twitter-ps-27.png" alt="William Candillon Tweet" width="50%">

<img src="https://raw.githubusercontent.com/codota/tabnine-vscode/master/assets/twitter-ps-7.png" alt="Imed Boumalek Tweet" width="50%">

<img src="https://raw.githubusercontent.com/codota/tabnine-vscode/master/assets/twitter-ps-14.png" alt="ramnivas Tweet" width="50%">

<img src="https://raw.githubusercontent.com/codota/tabnine-vscode/master/assets/twitter-ps-16.png" alt="bob paskar Tweet" width="50%">

<img src="https://raw.githubusercontent.com/codota/tabnine-vscode/master/assets/twitter-ps-19.png" alt="Nick Radford Tweet" width="50%">

<img src="https://raw.githubusercontent.com/codota/tabnine-vscode/master/assets/twitter-ps-28.png" alt="Hugues BR Tweet" width="50%">

<img src="https://raw.githubusercontent.com/codota/tabnine-vscode/master/assets/twitter-ps-32.png" alt="JohnyTheCarrot Tweet" width="50%">

<img src="https://raw.githubusercontent.com/codota/tabnine-vscode/master/assets/twitter-ps-33.png" alt="Donald E Fredrick Tweet" width="50%">

<img src="https://raw.githubusercontent.com/codota/tabnine-vscode/master/assets/twitter-ps-36.png" alt="Joshua Kelly Tweet" width="50%">

<img src="https://raw.githubusercontent.com/codota/tabnine-vscode/master/assets/twitter-ps-38.png" alt="JDerek Braid Tweet" width="50%">

---

- **Q: Can I install Tabnine on multiple machines?**
- A: You can use your Tabnine license on as many computers and operating systems as you like. All Tabnine Licenses are per-user, rather than per-machine.
  <br />
  <br />

- **Q: Is there a Tabnine Student program?**
- A: Yes, If you’re a student, you can register for Tabnine Pro for FREE using your school email address. [Get Tabnine Student now](https://www.tabnine.com/students?utm_source=ide_marketplace&utm_medium=organic&utm_campaign=jupyter_lab_marketplace)
  <br />
  <br />

- **Q: Does Tabnine use a model trained on safe, open-source code for completions?**
- A: Yes, all Tabnine code completions are based on trusted, open-source code with permissive licenses.
  <br />
  <br />

- **Q: Does the Tabnine Private Codebase AI share my code?**
- A: NEVER! Your code is always kept local and 100% private for you and your team. It’s never used to train the Tabnine Private Codebase AI - That’s the Tabnine Privacy Promise.
  <br />
  <br />

- **Q: Do All Three Tabnie AI Models work together?**
- A: Yes, the three models work in tandem, simultaneously providing unparalleled AI accuracy. Tabnine’s Open-Source Trained AI bases its suggestions on trusted public code with permissive licenses while the Private Codebase AI and Team Trained AI learn from you and your team’s preferences, code selections, and ongoing AI interactions.
  <br />
  <br />

- **Q: Can I run Tabnine locally, or do I need to use the Cloud?**
- A: You can run Tabnine locally or on the cloud, you choose! Regardless, your code is never shared or used as part of Tabnine’s Open-Source Trained AI - That’s the Tabnine Privacy Promise.
  <br />
  <br />

- **Q: Does Tabnine work in multiple IDEs?**
- A: Yes, Tabnine works with all your favorite IDEs, and in the most popular languages, libraries, and frameworks. See the full list of IDEs and languages [HERE](https://www.tabnine.com/install?utm_source=ide_marketplace&utm_medium=organic&utm_campaign=jupyter_lab_marketplace)
  <br />
  <br />

- **Q: What is the difference between Tabnine Basic and Tabnine Pro?**
- A: Tabnine Pro uses our advanced AI Model trained on more than a billion lines of open-source code and works with teams of up to 30. Tabnine Basic uses a smaller AI model and works with teams of three or less.
  <br />
  <br />

- **Q: What type of online payments are accepted?**
- A: Tabnine accepts all major credit cards and debit cards, including Visa, Mastercard, American Express, and more. Tabnine also accepts PayPal, Google Pay, Apple Pay, as well as additional payment options that may be available in your specific location (such as Alipay).
